Enum Change
pub enum Change {
Delete,
Subsume,
}Expand description
Change a function entry.
Variants
Delete
delete this entry from a function.
Be wary! Only delete entries that are guaranteed to be not useful.
Subsume
subsume this entry so that it cannot be queried or extracted, but still can be checked.
Note that this is currently forbidden for functions with custom merges.