pub enum GenericExpr<Head, Leaf> {
Var(Span, Leaf),
Call(Span, Head, Vec<GenericExpr<Head, Leaf>>),
Lit(Span, Literal),
}Variants
Implementations
Sourceimpl<Head, Leaf> GenericExpr<Head, Leaf>
impl<Head, Leaf> GenericExpr<Head, Leaf>
pub fn visit_vars(&self, f: &mut impl FnMut(&Span, &Leaf))
pub fn span(&self) -> Span
pub fn is_var(&self) -> bool
pub fn get_var(&self) -> Option<Leaf>
pub fn ast_size(&self) -> usize
Sourcepub fn walk(
&self,
pre: &mut impl FnMut(&GenericExpr<Head, Leaf>),
post: &mut impl FnMut(&GenericExpr<Head, Leaf>),
)
pub fn walk( &self, pre: &mut impl FnMut(&GenericExpr<Head, Leaf>), post: &mut impl FnMut(&GenericExpr<Head, Leaf>), )
Traverse the expression tree, calling pre before visiting children
and post after visiting children. Visits all nodes in the tree.
Sourcepub fn fold<Out>(
&self,
f: &mut impl FnMut(&GenericExpr<Head, Leaf>, Vec<Out>) -> Out,
) -> Out
pub fn fold<Out>( &self, f: &mut impl FnMut(&GenericExpr<Head, Leaf>, Vec<Out>) -> Out, ) -> Out
Fold over the expression tree bottom-up, collecting results from children.
The function f is called on each node with the node itself and the results
from folding over its children. Results are computed from leaves to root.
Sourcepub fn find<Out>(
&self,
f: &mut impl FnMut(&GenericExpr<Head, Leaf>) -> Option<Out>,
) -> Option<Out>
pub fn find<Out>( &self, f: &mut impl FnMut(&GenericExpr<Head, Leaf>) -> Option<Out>, ) -> Option<Out>
Search for the first node matching a predicate, returning early once found. Traverses the tree in pre-order (top-down).
Sourcepub fn visit_exprs(
self,
f: &mut impl FnMut(GenericExpr<Head, Leaf>) -> GenericExpr<Head, Leaf>,
) -> GenericExpr<Head, Leaf>
pub fn visit_exprs( self, f: &mut impl FnMut(GenericExpr<Head, Leaf>) -> GenericExpr<Head, Leaf>, ) -> GenericExpr<Head, Leaf>
Applys f to all sub-expressions (including self)
bottom-up, collecting the results.
Sourcepub fn subst<Head2, Leaf2>(
&self,
subst_leaf: &mut impl FnMut(&Span, &Leaf) -> GenericExpr<Head2, Leaf2>,
subst_head: &mut impl FnMut(&Head) -> Head2,
) -> GenericExpr<Head2, Leaf2>
pub fn subst<Head2, Leaf2>( &self, subst_leaf: &mut impl FnMut(&Span, &Leaf) -> GenericExpr<Head2, Leaf2>, subst_head: &mut impl FnMut(&Head) -> Head2, ) -> GenericExpr<Head2, Leaf2>
subst replaces occurrences of variables and head symbols in the expression.
pub fn subst_leaf<Leaf2>( &self, subst_leaf: &mut impl FnMut(&Span, &Leaf) -> GenericExpr<Head, Leaf2>, ) -> GenericExpr<Head, Leaf2>
Sourcepub fn map_symbols<Head2, Leaf2>(
self,
head: &mut impl FnMut(Head) -> Head2,
leaf: &mut impl FnMut(Leaf) -> Leaf2,
) -> GenericExpr<Head2, Leaf2>
pub fn map_symbols<Head2, Leaf2>( self, head: &mut impl FnMut(Head) -> Head2, leaf: &mut impl FnMut(Leaf) -> Leaf2, ) -> GenericExpr<Head2, Leaf2>
Applies the provided head and leaf mappings to every symbol within the expression.
Sourcepub fn make_unresolved(self) -> GenericExpr<String, String>
pub fn make_unresolved(self) -> GenericExpr<String, String>
Converts all heads and leaves to strings.
pub fn vars(&self) -> impl Iterator<Item = Leaf>