pub fn get_max_underscores(program: &[GenericCommand<String, String>]) -> usizeExpand description
Computes the maximum number of underscores in any symbol name in the program.
pub fn get_max_underscores(program: &[GenericCommand<String, String>]) -> usizeComputes the maximum number of underscores in any symbol name in the program.