pub struct GenericFunctionDecl<Head, Leaf>{
pub name: String,
pub subtype: FunctionSubtype,
pub schema: Schema,
pub resolved_schema: Head,
pub merge: Option<GenericExpr<Head, Leaf>>,
pub cost: Option<DefaultCost>,
pub unextractable: bool,
pub internal_hidden: bool,
pub internal_let: bool,
pub span: Span,
pub term_constructor: Option<String>,
}Expand description
Represents the declaration of a function directly parsed from source syntax.
Fields
name: Stringsubtype: FunctionSubtypeschema: SchemaUntyped schema
resolved_schema: HeadResolved schema after typechecking is stored here, otherwise “”.
merge: Option<GenericExpr<Head, Leaf>>cost: Option<DefaultCost>unextractable: boolHidden functions are excluded from print-size output. Used for internal tables generated by proof production.
internal_let: boolGlobals are desugared to functions, with this flag set to true. This is used by visualization to handle globals differently.
span: Spanterm_constructor: Option<String>For view tables in proof encoding: the constructor to use for building terms from the first n-1 children during extraction.
Implementations
Sourceimpl GenericFunctionDecl<String, String>
impl GenericFunctionDecl<String, String>
Sourcepub fn function(
span: Span,
name: String,
schema: Schema,
merge: Option<GenericExpr<String, String>>,
) -> Self
pub fn function( span: Span, name: String, schema: Schema, merge: Option<GenericExpr<String, String>>, ) -> Self
Constructs a function
Sourcepub fn constructor(
span: Span,
name: String,
schema: Schema,
cost: Option<DefaultCost>,
unextractable: bool,
hidden: bool,
) -> Self
pub fn constructor( span: Span, name: String, schema: Schema, cost: Option<DefaultCost>, unextractable: bool, hidden: bool, ) -> Self
Constructs a constructor
Sourceimpl<Head, Leaf> GenericFunctionDecl<Head, Leaf>
impl<Head, Leaf> GenericFunctionDecl<Head, Leaf>
pub fn visit_exprs( self, f: &mut impl FnMut(GenericExpr<Head, Leaf>) -> GenericExpr<Head, Leaf>, ) -> GenericFunctionDecl<Head, Leaf>