pub struct GenericRule<Head, Leaf>{
pub span: Span,
pub head: GenericActions<Head, Leaf>,
pub body: Vec<GenericFact<Head, Leaf>>,
pub name: String,
pub ruleset: String,
}Fields
span: Spanhead: GenericActions<Head, Leaf>body: Vec<GenericFact<Head, Leaf>>name: StringA globally unique name for this rule in the EGraph.
ruleset: StringThe ruleset this rule belongs to. Defaults to "".
Implementations
Sourceimpl<Head, Leaf> GenericRule<Head, Leaf>
impl<Head, Leaf> GenericRule<Head, Leaf>
Sourcepub fn visit_exprs(
self,
f: &mut impl FnMut(GenericExpr<Head, Leaf>) -> GenericExpr<Head, Leaf>,
) -> GenericRule<Head, Leaf>
pub fn visit_exprs( self, f: &mut impl FnMut(GenericExpr<Head, Leaf>) -> GenericExpr<Head, Leaf>, ) -> GenericRule<Head, Leaf>
Applies f to every expression that appears in the rule body or head.
Sourcepub fn visit_actions(
self,
f: &mut impl FnMut(GenericAction<Head, Leaf>) -> GenericAction<Head, Leaf>,
) -> GenericRule<Head, Leaf>
pub fn visit_actions( self, f: &mut impl FnMut(GenericAction<Head, Leaf>) -> GenericAction<Head, Leaf>, ) -> GenericRule<Head, Leaf>
Applies f to each action in the rule head, leaving the body unchanged.
Sourcepub fn map_symbols<Head2, Leaf2>(
self,
head: &mut impl FnMut(Head) -> Head2,
leaf: &mut impl FnMut(Leaf) -> Leaf2,
) -> GenericRule<Head2, Leaf2>
pub fn map_symbols<Head2, Leaf2>( self, head: &mut impl FnMut(Head) -> Head2, leaf: &mut impl FnMut(Leaf) -> Leaf2, ) -> GenericRule<Head2, Leaf2>
Applies the provided head and leaf mappings to every symbol that appears in the rule.
Sourcepub fn make_unresolved(self) -> GenericRule<String, String>
pub fn make_unresolved(self) -> GenericRule<String, String>
Converts the rule into its unresolved representation by formatting heads and leaves.