pub struct ResolvedVar {
pub name: String,
pub sort: ArcSort,
pub is_global_ref: bool,
}Fields
name: Stringsort: ArcSortis_global_ref: boolIs this a reference to a global variable?
After the remove_globals pass, this should be false.
NB: we distinguish between a global reference and a global binding.
The current implementation of Eq and Hash does not take this field
into consideration.
Overall, the definition of equality between two ResolvedVars is dicey.