pub enum ConstraintError<Var, Value> {
InconsistentConstraint(Var, Value, Value),
UnconstrainedVar(Var),
NoConstraintSatisfied(Vec<ConstraintError<Var, Value>>),
ImpossibleCaseIdentified(ImpossibleConstraint),
}Expand description
Errors that can occur during constraint solving. These represent various ways that constraint satisfaction can fail.
Variants
InconsistentConstraint(Var, Value, Value)
A variable was assigned two different, incompatible values
UnconstrainedVar(Var)
A variable in the constraint range was not assigned any value
NoConstraintSatisfied(Vec<ConstraintError<Var, Value>>)
None of the alternative constraints in an XOR constraint could be satisfied
ImpossibleCaseIdentified(ImpossibleConstraint)
An impossible constraint was encountered during solving
Implementations
Sourceimpl ConstraintError<AtomTerm, ArcSort>
impl ConstraintError<AtomTerm, ArcSort>
Sourcepub fn to_type_error(&self) -> TypeError
pub fn to_type_error(&self) -> TypeError
Converts a ConstraintError produced by type checking into a type error.