Function assign

pub fn assign<Var, Value>(x: Var, v: Value) -> Box<dyn Constraint<Var, Value>>
where Var: Eq + PartialEq + Hash + Clone + Debug + 'static, Value: Clone + Debug + 'static,
Creates an assignment constraint that binds a variable to a specific value. The constraint fails if the variable is already assigned to a different value.