Function eq

pub fn eq<Var, Value>(x: Var, y: Var) -> Box<dyn Constraint<Var, Value>>
where Var: Eq + PartialEq + Hash + Clone + Debug + 'static, Value: Clone + Debug + 'static,
Creates an equality constraint between two variables. If one of the variable has a known value, the constraint propagates value to the other variable. If both variables have known but different values, the constraint fails.