Function implies

pub fn implies<Var, Value>(
    name: String,
    watch_vars: Vec<Var>,
    constraint: DelayedConstraintFn<Var, Value>,
) -> Box<dyn Constraint<Var, Value>>
where Var: Eq + PartialEq + Hash + Clone + Debug + 'static, Value: Clone + Debug + 'static,
Creates an implication constraint that activates when all watch variables are assigned. The constraint function is called with the values of the watch variables to generate the actual constraint.