Function impossible

pub fn impossible<Var, Value>(
    constraint: ImpossibleConstraint,
) -> Box<dyn Constraint<Var, Value>>
where Var: Eq + PartialEq + Hash + Clone + Debug + 'static, Value: Clone + Debug + 'static,
Creates a constraint that always fails with the given impossible constraint. This is used to signal type errors during constraint solving.