pub struct AllEqualTypeConstraint { /* private fields */ }Expand description
A type constraint that requires all or some arguments to have the same type.
See the with_all_arguments_sort, with_exact_length, and with_output_sort methods
for configuring the constraint.
Implementations
Sourceimpl AllEqualTypeConstraint
impl AllEqualTypeConstraint
Sourcepub fn new(name: &str, span: Span) -> AllEqualTypeConstraint
pub fn new(name: &str, span: Span) -> AllEqualTypeConstraint
Creates the AllEqualTypeConstraint.
Sourcepub fn into_box(self) -> Box<dyn TypeConstraint>
pub fn into_box(self) -> Box<dyn TypeConstraint>
Converts self into a boxed type constraint.
Sourcepub fn with_all_arguments_sort(self, sort: ArcSort) -> Self
pub fn with_all_arguments_sort(self, sort: ArcSort) -> Self
Requires all arguments to have the given sort.
If with_output_sort is not specified, this requirement
also applies to the output argument.
Sourcepub fn with_exact_length(self, exact_length: usize) -> Self
pub fn with_exact_length(self, exact_length: usize) -> Self
Requires the length of arguments to be exact_length.
Note this includes both input arguments and output argument.
Sourcepub fn with_output_sort(self, output_sort: ArcSort) -> Self
pub fn with_output_sort(self, output_sort: ArcSort) -> Self
Requires the output argument to have the given sort.