pub struct Problem<Var, Value> {
pub constraints: Vec<Box<dyn Constraint<Var, Value>>>,
pub range: HashSet<Var, BuildHasherDefault<FxHasher>>,
}Expand description
A constraint satisfaction problem consisting of constraints and a range of variables to solve for. The problem is considered solved when all variables in the range are assigned.
Fields
constraints: Vec<Box<dyn Constraint<Var, Value>>>The list of constraints that must be satisfied
range: HashSet<Var, BuildHasherDefault<FxHasher>>The set of variables that must be assigned a value for the problem to be considered solved