pub struct SimpleTypeConstraint { /* private fields */ }Expand description
A type constraint that assigns specific sorts to each argument position.
Constructs a set of Assign constraints that fully constrain the type of arguments.
Implementations