Struct RustRuleContext

pub struct RustRuleContext<'a, 'b> { /* private fields */ }
A wrapper around an ExecutionState for rules that are written in Rust. See the rust_rule documentation for an example of how to use this.

Implementations

Source

impl RustRuleContext<'_, '_>

pub fn value_to_base<T: BaseValue>(&self, x: Value) -> T

Convert from an egglog value to a Rust type.

pub fn value_to_container<T: ContainerValue>( &mut self, x: Value, ) -> Option<impl Deref<Target = T>>

Convert from an egglog value to reference of Rust container type.

See EGraph::value_to_container.

pub fn base_to_value<T: BaseValue>(&self, x: T) -> Value

Convert from a Rust type to an egglog value.

pub fn container_to_value<T: ContainerValue>(&mut self, x: T) -> Value

Convert from a Rust container type to an egglog value.

pub fn lookup(&mut self, table: &str, key: &[Value]) -> Option<Value>

Do a table lookup. This is potentially a mutable operation! For more information, see egglog_bridge::TableAction::lookup.

pub fn union(&mut self, x: Value, y: Value)

Union two values in the e-graph. For more information, see egglog_bridge::UnionAction::union.

pub fn insert(&mut self, table: &str, row: impl Iterator<Item = Value>)

Insert a row into a table. For more information, see egglog_bridge::TableAction::insert.

pub fn remove(&mut self, table: &str, key: &[Value])

Remove a row from a table. For more information, see egglog_bridge::TableAction::remove.

pub fn subsume(&mut self, table: &str, key: &[Value])

Subsume a row in a table. For more information, see egglog_bridge::TableAction::subsume.

pub fn panic(&mut self) -> Option<()>

Panic. You should also return None from your callback if you call this function, which this function hopefully makes easier by always returning None so that you can use ?.