pub struct Matches { /* private fields */ }Expand description
A collection of matches produced by a rule. The user can choose which matches to be fired.
Implementations
Sourceimpl Matches
impl Matches
Sourcepub fn match_size(&self) -> usize
pub fn match_size(&self) -> usize
The number of matches in total.
Sourcepub fn choose_all(&mut self)
pub fn choose_all(&mut self)
Pick all matches to be fired.
This is more efficient than calling choose for each match.