Struct BaseValues
pub struct BaseValues { /* private fields */ }Expand description
A registry for base value types and functions on them.
Implementations
impl BaseValues
impl BaseValues
pub fn register_type<P>(&mut self) -> BaseValueIdwhere
P: BaseValue,
pub fn register_type<P>(&mut self) -> BaseValueIdwhere
P: BaseValue,
Register the given type P as a base value type in this registry.
pub fn get_ty<P>(&self) -> BaseValueIdwhere
P: BaseValue,
pub fn get_ty<P>(&self) -> BaseValueIdwhere
P: BaseValue,
Get the [BaseValueId] for the given base value type P.
pub fn get_ty_by_id(&self, id: TypeId) -> BaseValueId
pub fn get_ty_by_id(&self, id: TypeId) -> BaseValueId
Get the [BaseValueId] for the given base value type id.