Struct ContainerValues

pub struct ContainerValues { /* private fields */ }

Implementations



impl ContainerValues

pub fn new() -> ContainerValues

pub fn for_each<C>(&self, f: impl FnMut(&C, Value))
where C: ContainerValue,

Iterate over the containers of the given type.

pub fn get_val<C>(&self, val: Value) -> Option<impl Deref<Target = C>>
where C: ContainerValue,

Get the container associated with the value val in the database. The caller must know the type of the container.

The return type of this function may contain lock guards. Attempts to modify the contents of the containers database may deadlock if the given guard has not been dropped.

pub fn register_val<C>( &self, container: C, exec_state: &mut ExecutionState<'_>, ) -> Value
where C: ContainerValue,

pub fn rebuild_all( &mut self, table_id: TableId, table: &WrappedTable, exec_state: &mut ExecutionState<'_>, ) -> bool

Apply the given rebuild to the contents of each container.

pub fn register_type<C>( &mut self, id_counter: CounterId, merge_fn: impl MergeFn + 'static, ) -> ContainerValueId
where C: ContainerValue,

Add a new container type to the given ContainerValue instance.

Container types need a meaans of generating fresh ids (id_counter) along with a means of merging conflicting ids (merge_fn).