pub struct I64Sort;Expand description
Signed 64-bit integers supporting these primitives:
- Arithmetic:
+,-,*,/,% - Bitwise:
&,|,^,<<,>>,not-i64 - Fallible comparisons:
<,>,<=,>= - Boolean comparisons:
bool-=,bool-<,bool->,bool-<=,bool->= - Other:
min,max,to-f64,to-string,log2
Note: fallible comparisons are used at the top-level of a query.
For example, this rule will only match if a is less than b.
(rule (... (< a b)) (...))On the other hand, boolean comparisons will always match, and so make sense to use inside expressions.