pub struct Function { /* private fields */ }Expand description
A function in the e-graph.
This contains the schema information of the function and the backend id of the function in the e-graph.
Implementations
Sourceimpl Function
impl Function
Sourcepub fn schema(&self) -> &ResolvedSchema
pub fn schema(&self) -> &ResolvedSchema
Get the schema of the function.
Sourcepub fn can_subsume(&self) -> bool
pub fn can_subsume(&self) -> bool
Whether this function supports subsumption.
Sourcepub fn is_let_binding(&self) -> bool
pub fn is_let_binding(&self) -> bool
Whether this is a let binding
Whether this function is internally hidden (e.g., compiler-generated helper tables that should not appear in user-facing listings).
Sourcepub fn term_constructor(&self) -> Option<&str>
pub fn term_constructor(&self) -> Option<&str>
The term-constructor name associated with this function table, if any. Set on view tables created by the term/proof encoding to refer back to the user-visible constructor name.