pub struct TermDag { /* private fields */ }Expand description
A hashconsing arena for Terms.
Implementations
Sourceimpl TermDag
impl TermDag
Sourcepub fn lookup(&self, node: &Term) -> TermId
pub fn lookup(&self, node: &Term) -> TermId
Convert the given term to its id.
Panics if the term does not already exist in this TermDag.
Sourcepub fn get(&self, id: TermId) -> &Term
pub fn get(&self, id: TermId) -> &Term
Convert the given id to the corresponding term.
Panics if the id is not valid.
Sourcepub fn app(&mut self, sym: String, children: Vec<TermId>) -> TermId
pub fn app(&mut self, sym: String, children: Vec<TermId>) -> TermId
Make and return a Term::App with the given head symbol and children,
and insert into the DAG if it is not already present.
Panics if any of the children are not already in the DAG.
Sourcepub fn var(&mut self, sym: String) -> TermId
pub fn var(&mut self, sym: String) -> TermId
Make and return a Term::Var with the given symbol, and insert into
the DAG if it is not already present.
Sourcepub fn expr_to_term(&mut self, expr: &GenericExpr<String, String>) -> TermId
pub fn expr_to_term(&mut self, expr: &GenericExpr<String, String>) -> TermId
Recursively converts the given expression to a term.
This involves inserting every subexpression into this DAG. Because TermDags are hashconsed, the resulting term is guaranteed to maximally share subterms.
Sourcepub fn term_to_expr(&self, term: &TermId, span: Span) -> Expr
pub fn term_to_expr(&self, term: &TermId, span: Span) -> Expr
Recursively converts the given term to an expression.
Panics if the term contains subterms that are not in the DAG.
Sourcepub fn to_string_with_let(
&self,
fresh: &mut SymbolGen,
term_id: TermId,
) -> String
pub fn to_string_with_let( &self, fresh: &mut SymbolGen, term_id: TermId, ) -> String
Prints a term to a string, putting let bindings for shared subterms.