Struct SymbolGen

pub struct SymbolGen { /* private fields */ }
Generates fresh symbols for internal use during typechecking and flattening. These are guaranteed not to collide with the user’s symbols because they use a reserved prefix.

Implementations

Source

impl SymbolGen

pub fn new(reserved_string: String) -> Self

pub fn has_been_used(&self) -> bool

pub fn reserved_prefix(&self) -> &str

pub fn is_reserved(&self, symbol: &str) -> bool