pub trait FromValue: Sized {
// Required method
fn from_value(value: Value, bv: &BaseValues) -> Self;
}Expand description
Convert an egglog Value back into a Rust value. Open trait:
impl for your own types if you want them to flow out of
function_entries / query rows.
Required Methods
fn from_value(value: Value, bv: &BaseValues) -> Self
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".