pub enum GenericNCommand<Head, Leaf>{
Show 18 variants
Sort(Span, String, Option<(String, Vec<GenericExpr<String, String>>)>),
Function(GenericFunctionDecl<Head, Leaf>),
AddRuleset(Span, String),
UnstableCombinedRuleset(Span, String, Vec<String>),
NormRule {
rule: GenericRule<Head, Leaf>,
},
CoreAction(GenericAction<Head, Leaf>),
Extract(Span, GenericExpr<Head, Leaf>, GenericExpr<Head, Leaf>),
RunSchedule(GenericSchedule<Head, Leaf>),
PrintOverallStatistics(Span, Option<String>),
Check(Span, Vec<GenericFact<Head, Leaf>>),
PrintFunction(Span, String, Option<usize>, Option<String>, PrintFunctionMode),
PrintSize(Span, Option<String>),
Output {
span: Span,
file: String,
exprs: Vec<GenericExpr<Head, Leaf>>,
},
Push(usize),
Pop(Span, usize),
Fail(Span, Box<GenericNCommand<Head, Leaf>>),
Input {
span: Span,
name: String,
file: String,
},
UserDefined(Span, String, Vec<Expr>),
}Expand description
A NCommand is a desugared Command, where syntactic sugars
like Command::Datatype and Command::Rewrite
are eliminated.
Most of the heavy lifting in egglog is done over NCommands.
GenericNCommand is a generalization of NCommand, like how GenericCommand
is a generalization of Command, allowing annotations over Head and Leaf.
TODO: The name “NCommand” used to denote normalized command, but this meaning is obsolete. A future PR should rename this type to something like “DCommand”.
Variants
Sort(Span, String, Option<(String, Vec<GenericExpr<String, String>>)>)
Function(GenericFunctionDecl<Head, Leaf>)
AddRuleset(Span, String)
UnstableCombinedRuleset(Span, String, Vec<String>)
NormRule
Fields

rule: GenericRule<Head, Leaf>CoreAction(GenericAction<Head, Leaf>)
Extract(Span, GenericExpr<Head, Leaf>, GenericExpr<Head, Leaf>)
RunSchedule(GenericSchedule<Head, Leaf>)
PrintOverallStatistics(Span, Option<String>)
Check(Span, Vec<GenericFact<Head, Leaf>>)
PrintFunction(Span, String, Option<usize>, Option<String>, PrintFunctionMode)
PrintSize(Span, Option<String>)
Output
Push(usize)
Pop(Span, usize)
Fail(Span, Box<GenericNCommand<Head, Leaf>>)
Input
UserDefined(Span, String, Vec<Expr>)
Implementations
Sourceimpl<Head, Leaf> GenericNCommand<Head, Leaf>
impl<Head, Leaf> GenericNCommand<Head, Leaf>
pub fn to_command(&self) -> GenericCommand<Head, Leaf>
pub fn visit_exprs( self, f: &mut impl FnMut(GenericExpr<Head, Leaf>) -> GenericExpr<Head, Leaf>, ) -> Self