pub fn sanitize_internal_names<Head, Leaf>(
program: &[GenericCommand<Head, Leaf>],
) -> Vec<GenericCommand<String, String>>Expand description
Sanitizes internal names so they do not contain any internal characters. This enables printing desugared egglog in a way that can be re-parsed.