Struct GenericFunctionDecl

pub struct GenericFunctionDecl<Head, Leaf>
where Head: Clone + Display, Leaf: Clone + PartialEq + Eq + Display + Hash,
{ pub name: String, pub subtype: FunctionSubtype, pub schema: Schema, pub merge: Option<GenericExpr<Head, Leaf>>, pub cost: Option<DefaultCost>, pub unextractable: bool, pub let_binding: bool, pub span: Span, }
Represents the declaration of a function directly parsed from source syntax.

Fields

name: Stringsubtype: FunctionSubtypeschema: Schemamerge: Option<GenericExpr<Head, Leaf>>cost: Option<DefaultCost>unextractable: boollet_binding: bool

Globals are desugared to functions, with this flag set to true. This is used by visualization to handle globals differently.

span: Span

Implementations

Source

impl GenericFunctionDecl<String, String>

pub fn function( span: Span, name: String, schema: Schema, merge: Option<GenericExpr<String, String>>, ) -> Self

Constructs a function

pub fn constructor( span: Span, name: String, schema: Schema, cost: Option<DefaultCost>, unextractable: bool, ) -> Self

Constructs a constructor

pub fn relation(span: Span, name: String, input: Vec<String>) -> Self

Constructs a relation

Source

impl<Head, Leaf> GenericFunctionDecl<Head, Leaf>
where Head: Clone + Display, Leaf: Clone + PartialEq + Eq + Display + Hash,

pub fn visit_exprs( self, f: &mut impl FnMut(GenericExpr<Head, Leaf>) -> GenericExpr<Head, Leaf>, ) -> GenericFunctionDecl<Head, Leaf>