pub type FunctionDecl = GenericFunctionDecl<String, String>;Aliased Type
struct FunctionDecl {
pub name: String,
pub subtype: FunctionSubtype,
pub schema: Schema,
pub merge: Option<GenericExpr<String, String>>,
pub cost: Option<u64>,
pub unextractable: bool,
pub let_binding: bool,
pub span: Span,
}Fields
name: Stringsubtype: FunctionSubtypeschema: Schemamerge: Option<GenericExpr<String, String>>cost: Option<u64>unextractable: boollet_binding: boolGlobals are desugared to functions, with this flag set to true. This is used by visualization to handle globals differently.
span: Span