pub type ResolvedExpr = GenericExpr<ResolvedCall, ResolvedVar>;Expand description
A generated expression is an expression that is generated by the system and does not have annotations.
Aliased Type
pub enum ResolvedExpr {
Var(Span, ResolvedVar),
Call(Span, ResolvedCall, Vec<GenericExpr<ResolvedCall, ResolvedVar>>),
Lit(Span, Literal),
}