pub fn assign<Var, Value>(x: Var, v: Value) -> Box<dyn Constraint<Var, Value>>Expand description
Creates an assignment constraint that binds a variable to a specific value. The constraint fails if the variable is already assigned to a different value.