pub fn eq<Var, Value>(x: Var, y: Var) -> Box<dyn Constraint<Var, Value>>Expand description
Creates an equality constraint between two variables. If one of the variable has a known value, the constraint propagates value to the other variable. If both variables have known but different values, the constraint fails.