pub fn implies<Var, Value>(
name: String,
watch_vars: Vec<Var>,
constraint: DelayedConstraintFn<Var, Value>,
) -> Box<dyn Constraint<Var, Value>>Expand description
Creates an implication constraint that activates when all watch variables are assigned. The constraint function is called with the values of the watch variables to generate the actual constraint.