pub fn impossible<Var, Value>(
constraint: ImpossibleConstraint,
) -> Box<dyn Constraint<Var, Value>>Expand description
Creates a constraint that always fails with the given impossible constraint. This is used to signal type errors during constraint solving.