pub struct Extractor<C: Cost + Ord + Eq + Clone + Debug> { /* private fields */ }Expand description
The default, Bellman-Ford like extractor. This extractor is optimal for CostModel.
Implementations
Sourceimpl<C: Cost + Ord + Eq + Clone + Debug> Extractor<C>
impl<C: Cost + Ord + Eq + Clone + Debug> Extractor<C>
Sourcepub fn compute_costs_from_rootsorts(
rootsorts: Option<Vec<ArcSort>>,
egraph: &EGraph,
cost_model: impl CostModel<C> + 'static,
) -> Self
pub fn compute_costs_from_rootsorts( rootsorts: Option<Vec<ArcSort>>, egraph: &EGraph, cost_model: impl CostModel<C> + 'static, ) -> Self
Bulk of the computation happens at initialization time. The later extractions only reuses saved results. This means a new extractor must be created if the egraph changes. Holding a reference to the egraph would enforce this but prevents the extractor being reused.
For convenience, if the rootsorts is None, it defaults to extract all extractable rootsorts.
Sourcepub fn extract_best_with_sort(
&self,
egraph: &EGraph,
termdag: &mut TermDag,
value: Value,
sort: ArcSort,
) -> Option<(C, Term)>
pub fn extract_best_with_sort( &self, egraph: &EGraph, termdag: &mut TermDag, value: Value, sort: ArcSort, ) -> Option<(C, Term)>
Extract the best term of a value from a given sort.
This function expects the sort to be already computed, which can be one of the rootsorts, or reachable from rootsorts, or primitives, or containers of computed sorts.
Sourcepub fn extract_best(
&self,
egraph: &EGraph,
termdag: &mut TermDag,
value: Value,
) -> Option<(C, Term)>
pub fn extract_best( &self, egraph: &EGraph, termdag: &mut TermDag, value: Value, ) -> Option<(C, Term)>
A convenience method for extraction.
This expects the value to be of the unique sort the extractor has been initialized with
Sourcepub fn extract_variants_with_sort(
&self,
egraph: &EGraph,
termdag: &mut TermDag,
value: Value,
nvariants: usize,
sort: ArcSort,
) -> Vec<(C, Term)>
pub fn extract_variants_with_sort( &self, egraph: &EGraph, termdag: &mut TermDag, value: Value, nvariants: usize, sort: ArcSort, ) -> Vec<(C, Term)>
Extract variants of an e-class.
The variants are selected by first picking nvairants e-nodes with the lowest cost from the e-class
and then extracting a term from each e-node.