pub trait Scheduler:
DynClone
+ Send
+ Sync {
// Required method
fn filter_matches(
&mut self,
rule: &str,
ruleset: &str,
matches: &mut Matches,
) -> bool;
// Provided method
fn can_stop(&mut self, rules: &[&str], ruleset: &str) -> bool { ... }
}Expand description
A scheduler decides which matches to be applied for a rule.
The matches that are not chosen in this iteration will be delayed to the next iteration.