pub struct SymbolGen { /* private fields */ }Expand description
Generates fresh symbols for internal use during typechecking and flattening. These are guaranteed not to collide with the user’s symbols because they use a reserved prefix.
Implementations